@@ -74,7 +74,6 @@ typedef struct
 	GHashTable		*vfuncs;		/* string:pointer */
 	GMutex			 vfuncs_mutex;
 	gboolean		 enabled;
-	GType			 app_gtype;
 	gchar			*locale;		/* allow-none */
 	gchar			*language;		/* allow-none */
 	gchar			*name;
@@ -441,59 +440,6 @@ gs_plugin_set_enabled (GsPlugin *plugin, gboolean enabled)
 	priv->enabled = enabled;
 }
 
-/**
- * gs_plugin_get_app_gtype:
- * @plugin: a #GsPlugin
- *
- * Gets the native application GType.
- *
- * Returns: a #GType, e.g. %GS_TYPE_APP
- *
- * Since: 3.26
- **/
-GType
-gs_plugin_get_app_gtype (GsPlugin *plugin)
-{
-	GsPluginPrivate *priv = gs_plugin_get_instance_private (plugin);
-	return priv->app_gtype;
-}
-
-/**
- * gs_plugin_set_app_gtype:
- * @plugin: a #GsPlugin
- * @app_gtype: the #GType state
- *
- * Sets the native application GType.
- *
- * Since: 3.26
- **/
-void
-gs_plugin_set_app_gtype (GsPlugin *plugin, GType app_gtype)
-{
-	GsPluginPrivate *priv = gs_plugin_get_instance_private (plugin);
-	priv->app_gtype = app_gtype;
-}
-
-/**
- * gs_plugin_app_new:
- * @plugin: a #GsPlugin
- * @id: an application ID
- *
- * Creates a GsApp, which may possibly be a subclassed type.
- * To set the type used when creating objects, plugins must use
- * gs_plugin_set_app_gtype() with a custom #GType.
- *
- * Returns: a #GsApp
- *
- * Since: 3.26
- **/
-GsApp *
-gs_plugin_app_new (GsPlugin *plugin, const gchar *id)
-{
-	GsPluginPrivate *priv = gs_plugin_get_instance_private (plugin);
-	return GS_APP (g_object_new (priv->app_gtype, "id", id, NULL));
-}
-
 /**
  * gs_plugin_get_name:
  * @plugin: a #GsPlugin
@@ -813,7 +759,7 @@ gs_plugin_set_profile (GsPlugin *plugin, AsProfile *profile)
  * gs_plugin_get_soup_session:
  * @plugin: a #GsPlugin
  *
- * Gets the soup session that plugins can use when downloading.
+ * Gets the soup session that this plugin can use when downloading.
  *
  * Returns: the #SoupSession
  *
@@ -831,7 +777,7 @@ gs_plugin_get_soup_session (GsPlugin *plugin)
  * @plugin: a #GsPlugin
  * @soup_session: a #SoupSession
  *
- * Sets the soup session that plugins will use when downloading.
+ * Sets the soup session that this plugin will use when downloading.
  *
  * Since: 3.22
  **/
@@ -1550,6 +1496,7 @@ void
 gs_plugin_cache_remove (GsPlugin *plugin, const gchar *key)
 {
 	GsPluginPrivate *priv = gs_plugin_get_instance_private (plugin);
+	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&priv->cache_mutex);
 
 	g_return_if_fail (GS_IS_PLUGIN (plugin));
 	g_return_if_fail (key != NULL);
@@ -1593,6 +1540,8 @@ gs_plugin_cache_add (GsPlugin *plugin, const gchar *key, GsApp *app)
 	if (key == NULL)
 		key = gs_app_get_unique_id (app);
 
+	g_return_if_fail (key != NULL);
+
 	/* global, so using internal unique_id */
 	if (gs_plugin_has_flags (plugin, GS_PLUGIN_FLAGS_GLOBAL_CACHE)) {
 		if (!as_utils_unique_id_valid (key)) {
@@ -2211,7 +2160,6 @@ gs_plugin_init (GsPlugin *plugin)
 		priv->rules[i] = g_ptr_array_new_with_free_func (g_free);
 
 	priv->enabled = TRUE;
-	priv->app_gtype = GS_TYPE_APP;
 	priv->scale = 1;
 	priv->profile = as_profile_new ();
 	priv->cache = g_hash_table_new_full ((GHashFunc) as_utils_unique_id_hash,
