@@ -85,6 +85,8 @@ const gchar	*gs_plugin_get_locale			(GsPlugin	*plugin);
 const gchar	*gs_plugin_get_language			(GsPlugin	*plugin);
 AsProfile	*gs_plugin_get_profile			(GsPlugin	*plugin);
 SoupSession	*gs_plugin_get_soup_session		(GsPlugin	*plugin);
+void		 gs_plugin_set_soup_session		(GsPlugin	*plugin,
+							 SoupSession	*soup_session);
 void		 gs_plugin_add_auth			(GsPlugin	*plugin,
 							 GsAuth		*auth);
 GsAuth		*gs_plugin_get_auth_by_id		(GsPlugin	*plugin,
