@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2013-2016 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2013-2017 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -203,6 +203,11 @@ gs_utils_get_cache_filename (const gchar *kind,
 				     kind,
 				     NULL);
 	cachedir_file = g_file_new_for_path (cachedir);
+	if (g_file_query_exists (cachedir_file, NULL) &&
+	    flags & GS_UTILS_CACHE_FLAG_ENSURE_EMPTY) {
+		if (!gs_utils_rmtree (cachedir, error))
+			return FALSE;
+	}
 	if (!g_file_query_exists (cachedir_file, NULL) &&
 	    !g_file_make_directory_with_parents (cachedir_file, NULL, error))
 		return NULL;
@@ -678,11 +683,13 @@ gs_utils_error_convert_gio (GError **perror)
 		return FALSE;
 	switch (error->code) {
 	case G_IO_ERROR_FAILED:
-	case G_IO_ERROR_TIMED_OUT:
 	case G_IO_ERROR_NOT_FOUND:
 	case G_IO_ERROR_EXISTS:
 		error->code = GS_PLUGIN_ERROR_FAILED;
 		break;
+	case G_IO_ERROR_TIMED_OUT:
+		error->code = GS_PLUGIN_ERROR_TIMED_OUT;
+		break;
 	case G_IO_ERROR_NOT_SUPPORTED:
 		error->code = GS_PLUGIN_ERROR_NOT_SUPPORTED;
 		break;
@@ -961,4 +968,35 @@ gs_user_agent (void)
 	return PACKAGE_NAME "/" PACKAGE_VERSION;
 }
 
+/**
+ * gs_utils_append_key_value:
+ * @str: A #GString
+ * @align_len: The alignment of the @value compared to the @key
+ * @key: The text to use as a title
+ * @value: The text to use as a value
+ *
+ * Adds a line to an existing string, padding the key to a set number of spaces.
+ *
+ * Since: 3.26
+ */
+void
+gs_utils_append_key_value (GString *str, gsize align_len,
+			   const gchar *key, const gchar *value)
+{
+	gsize len = 0;
+
+	g_return_if_fail (str != NULL);
+	g_return_if_fail (value != NULL);
+
+	if (key != NULL) {
+		len = strlen (key) + 2;
+		g_string_append (str, key);
+		g_string_append (str, ": ");
+	}
+	for (gsize i = len; i < align_len + 1; i++)
+		g_string_append (str, " ");
+	g_string_append (str, value);
+	g_string_append (str, "\n");
+}
+
 /* vim: set noexpandtab: */
