@@ -102,6 +102,11 @@ void
 gs_plugin_initialize (GsPlugin *plugin)
 {
 	GsPluginData *priv = gs_plugin_alloc_data (plugin, sizeof(GsPluginData));
+#if FWUPD_CHECK_VERSION(1,0,3)
+	g_autofree gchar *user_agent = NULL;
+#endif
+	g_autoptr(SoupSession) soup_session = NULL;
+
 	priv->client = fwupd_client_new ();
 	priv->to_download = g_ptr_array_new_with_free_func (g_free);
 	priv->to_ignore = g_ptr_array_new_with_free_func (g_free);
@@ -120,6 +125,22 @@ gs_plugin_initialize (GsPlugin *plugin)
 	}
 #endif
 
+#if FWUPD_CHECK_VERSION(1,0,3)
+	/* use a custom user agent to provide the fwupd version */
+	user_agent = fwupd_build_user_agent (PACKAGE_NAME, PACKAGE_VERSION);
+	soup_session = soup_session_new_with_options (SOUP_SESSION_USER_AGENT, user_agent,
+						      SOUP_SESSION_TIMEOUT, 10,
+						      NULL);
+#else
+	/* use a custom session with the content decoder turned off */
+	soup_session = soup_session_new_with_options (SOUP_SESSION_USER_AGENT, gs_user_agent (),
+						      SOUP_SESSION_TIMEOUT, 10,
+						      NULL);
+#endif
+	soup_session_remove_feature_by_type (soup_session,
+					     SOUP_TYPE_CONTENT_DECODER);
+	gs_plugin_set_soup_session (plugin, soup_session);
+
 	/* set name of MetaInfo file */
 	gs_plugin_set_appstream_id (plugin, "org.gnome.Software.Plugin.Fwupd");
 }
