@@ -501,6 +501,11 @@ gs_plugin_packagekit_refine_details_app (GsPlugin *plugin,
 						AS_URL_KIND_HOMEPAGE,
 						pk_details_get_url (details));
 			}
+			if (gs_app_get_description (app) == NULL) {
+				gs_app_set_description (app,
+				                        GS_APP_QUALITY_LOWEST,
+				                        pk_details_get_description (details));
+			}
 			size += pk_details_get_size (details);
 			break;
 		}
@@ -543,6 +548,8 @@ gs_plugin_packagekit_refine_details2 (GsPlugin *plugin,
 			g_ptr_array_add (package_ids, g_strdup (package_id));
 		}
 	}
+	if (package_ids->len == 0)
+		return TRUE;
 	g_ptr_array_add (package_ids, NULL);
 
 	data.app = NULL;
